@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.14 2003/06/16 18:32:16 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.15 2003/06/22 10:11:09 fuyu Exp $
  */
 
 #include "config.h"
@@ -87,6 +87,8 @@ static gboolean start_thread_rendering(OchushaBBSThread *thread,
 static gboolean render_response(OchushaBBSThread *thread, gint number,
 				const OchushaBBSResponse *response,
 				gpointer user_data);
+static gboolean render_broken_response(OchushaBBSThread *thread, gint number,
+				       gpointer user_data);
 static gboolean end_thread_rendering(OchushaBBSThread *thread,
 				     gboolean finished,
 				     gpointer user_data);
@@ -833,6 +835,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
 				     job_args->number_of_responses,
 				     start_thread_rendering,
 				     render_response,
+				     render_broken_response,
 				     end_thread_rendering,
 				     &context);
 
@@ -1031,6 +1034,70 @@ render_response(OchushaBBSThread *thread, gint number,
 }
 
 
+static gboolean
+render_broken_response(OchushaBBSThread *thread, gint number,
+		       gpointer user_data)
+{
+  RendererContext *context = (RendererContext *)user_data;
+  BBSThreadView *view = context->view;
+  BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
+  char buffer[13];
+#if DEBUG_GUI_MOST
+  fprintf(stderr, "rendering response #%d, last_read_number=%d\n",
+	  number, context->last_read_number);
+#endif
+
+  if (context->last_read_number >= 0)
+    {
+      info->offsets[number] = bbs_thread_view_get_current_offset(view);
+    }
+
+  if (number == context->last_read_number)
+    {
+      /* ɥ쥹*/
+      info->last_read = bbs_thread_view_create_mark(view);
+      info->next_mark = info->last_read;
+      gdk_threads_enter();
+      bbs_thread_view_scroll_to_mark(view, info->last_read);
+      gdk_threads_leave();
+    }
+
+  if (thread->number_of_responses_read < number)
+    {
+      thread->number_of_responses_read = number;
+      update_threadlist_entry(context->application, thread);
+    }
+
+  snprintf(buffer, 13, "\n%d", number);
+
+  gdk_threads_enter();
+
+#if ENABLE_RENDERING_ON_IDLE
+  while (!try_get_rendering_right(context->application,
+				  info->response_source_buffer,
+				  thread))
+    {
+      gdk_threads_leave();
+      ochusha_async_buffer_wait(info->response_source_buffer,
+				"bbs_thread_ui.c: each_response_cb()");
+      gdk_threads_enter();
+    }
+#endif
+  bbs_thread_view_append_text(view, buffer, -1);
+  bbs_thread_view_append_text(view, LARGE_COLON, 3);
+  bbs_thread_view_append_text(view, LARGE_COLON, 3);
+  bbs_thread_view_append_text(view, _("[broken here]\n"), -1);
+
+  bbs_thread_view_push_tag(view, context->response_paragraph_tag);
+  bbs_thread_view_append_text(view, _("[broken here]\n"), -1);
+  bbs_thread_view_pop_tags(view, context->response_paragraph_tag);
+
+  gdk_threads_leave();
+
+  return TRUE;
+}
+
+
 static gboolean
 end_thread_rendering(OchushaBBSThread *thread, gboolean finished,
 		     gpointer user_data)
@@ -1476,7 +1543,8 @@ render_popup_response(PopupContext *popup_context,
   gdk_threads_leave();
   ochusha_bbs_thread_parse_responses(thread, buffer,
 				     response_from - 1, num_responses,
-				     NULL, render_response, NULL,
+				     NULL, render_response,
+				     render_broken_response, NULL,
 				     &popup_context->renderer_context);
   gdk_threads_enter();
 
