@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.4 2003/05/25 08:47:13 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.6 2003/06/16 18:32:16 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -70,23 +70,14 @@ typedef struct _BBSThreadGUIInfo
 
   gboolean rendering_done;
 
-  /* ɽDATեΥХåե */
-  OchushaAsyncBuffer *dat_buffer;
+  /* ɽΥΥե(DATե)ΥХåե */
+  OchushaAsyncBuffer *response_source_buffer;
 
   /* Ǹ˳ưʹߤΥ */
   gint view_ignored;
 } BBSThreadGUIInfo;
 
 
-#if 0
-/* ThreadlistEntryStateĥƻȤ */
-typedef enum
-{
-  BBS_THREAD_STARTUP = 1 << 2,
-} ThreadlistEntryState;
-#endif
-
-
 void prepare_thread_ui_initialization(OchushaApplication *application);
 void initialize_thread_ui(OchushaApplication *application);
 BBSThreadGUIInfo * ensure_bbs_thread_info(OchushaBBSThread *thread);
