@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.8 2003/06/06 19:37:23 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.12 2003/06/12 02:02:08 fuyu Exp $
  */
 
 #include "config.h"
@@ -48,6 +48,7 @@
 
 
 static GtkTextTag *get_alt_link_tag(BBSThreadView *view);
+static GtkTextTag *get_alt_sage_tag(BBSThreadView *view);
 static void bbs_thread_view_class_init(BBSThreadViewClass *klass);
 static void bbs_thread_view_init(BBSThreadView *view);
 static void bbs_thread_view_finalize(GObject *object);
@@ -132,6 +133,7 @@ static gint bbs_thread_view_signals[LAST_SIGNAL] = { 0, 0, 0, 0, 0, 0, 0 };
 static GtkTextTagTable *default_tag_table;
 
 static GtkTextTag *link_tags[2];
+static GtkTextTag *sage_tags[2];
 
 
 static GtkTextTag *
@@ -143,6 +145,15 @@ get_alt_link_tag(BBSThreadView *view)
 }
 
 
+static GtkTextTag *
+get_alt_sage_tag(BBSThreadView *view)
+{
+  GtkTextTag *sage_tag = sage_tags[view->alt_sage_tag];
+  view->alt_sage_tag = (view->alt_sage_tag + 1) & 1;
+  return sage_tag;
+}
+
+
 GtkTextTagTable *
 bbs_thread_view_class_get_default_tag_table(BBSThreadViewClass *klass)
 {
@@ -209,6 +220,26 @@ bbs_thread_view_class_init(BBSThreadViewClass *klass)
   gtk_text_tag_table_add(default_tag_table, tag);
   link_tags[1] = tag;
 
+  /*
+   * ƱΥʣϢ³Ƥ硢GtkTextBufferǸʬĤʤ
+   * Τǡ2(sage0sage1)ߤ˻ȤƱ˰
+   */
+  tag = gtk_text_tag_new("sage0");
+  g_object_set(G_OBJECT(tag),
+	       "foreground", "purple",
+	       "underline", PANGO_UNDERLINE_SINGLE,
+	       NULL);
+  gtk_text_tag_table_add(default_tag_table, tag);
+  sage_tags[0] = tag;
+
+  tag = gtk_text_tag_new("sage1");
+  g_object_set(G_OBJECT(tag),
+	       "foreground", "purple",
+	       "underline", PANGO_UNDERLINE_SINGLE,
+	       NULL);
+  gtk_text_tag_table_add(default_tag_table, tag);
+  sage_tags[1] = tag;
+
   tag = gtk_text_tag_new("response_paragraph");
   g_object_set(G_OBJECT(tag),
 	       "indent", 0,
@@ -263,7 +294,7 @@ bbs_thread_view_class_init(BBSThreadViewClass *klass)
 		 G_TYPE_FROM_CLASS(klass),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(BBSThreadViewClass, link_mouse_press),
-		 _gtk_boolean_handled_accumulator, NULL,
+		 NULL, NULL,
 		 ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING,
 		 G_TYPE_BOOLEAN, 3,
 		 GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE,
@@ -274,7 +305,7 @@ bbs_thread_view_class_init(BBSThreadViewClass *klass)
 		 G_TYPE_FROM_CLASS(klass),
 		 G_SIGNAL_RUN_LAST,
 		 G_STRUCT_OFFSET(BBSThreadViewClass, link_mouse_release),
-		 _gtk_boolean_handled_accumulator, NULL,
+		 NULL, NULL,
 		 ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING,
 		 G_TYPE_BOOLEAN, 3,
 		 GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE,
@@ -538,7 +569,22 @@ text_view_get_iter_at_link_tag_from_event(GtkTextView *text_view,
       /* Ƭ˰ư */
       return gtk_text_iter_backward_to_tag_toggle(iter, link_tags[1]);
     }
-  else
+  else if (gtk_text_iter_has_tag(iter, sage_tags[0]))
+    {	/* sage_tags[0]ǰϤޤƤϰϤؤƤ */
+      if (gtk_text_iter_begins_tag(iter, sage_tags[0]))
+	return TRUE;	/* ƬؤƤ */
+
+      /* Ƭ˰ư */
+      return gtk_text_iter_backward_to_tag_toggle(iter, sage_tags[0]);
+    }
+  else if (gtk_text_iter_has_tag(iter, sage_tags[1]))
+    {	/* sage_tags[1]ؤƤ */
+      if (gtk_text_iter_begins_tag(iter, sage_tags[1]))
+	return TRUE;	/* ƬؤƤ */
+
+      /* Ƭ˰ư */
+      return gtk_text_iter_backward_to_tag_toggle(iter, sage_tags[1]);
+    }
     return FALSE;
 }
 
@@ -700,7 +746,7 @@ button_press_event_cb(GtkTextView *text_view, GdkEventButton *event,
 		    bbs_thread_view->thread,
 		    link,
 		    &handled);
-      return handled;
+      return TRUE;
     }
 
   return FALSE;
@@ -733,7 +779,7 @@ button_release_event_cb(GtkTextView *text_view, GdkEventButton *event,
 		    bbs_thread_view->thread,
 		    link,
 		    &handled);
-      return handled;
+      return TRUE;
     }
 
   return FALSE;
@@ -921,6 +967,33 @@ bbs_thread_view_append_text_as_link(BBSThreadView *view,
 }
 
 
+/*
+ * MEMO: textlen byteʬ󥯤äݤɽʸȤƥХåե
+ *       linkȤʸϸ˥ʥΰȤƻȤͽꡣ
+ *       textˤ"link"դtextƬʸΥХåե
+ *       offsetʸlinkؤΥϥåơ֥Ͽ롣
+ *       Ƥ"sage"ΤߤǤ뤳Ȥɽ뤿ᡢ̾Υ󥯤ȤϿѤ롣
+ */
+void
+bbs_thread_view_append_text_as_sage(BBSThreadView *view,
+				    const gchar *text, int len,
+				    const gchar *link)
+{
+  GtkTextIter start;
+  gint start_offset;
+
+  g_return_if_fail(IS_BBS_THREAD_VIEW(view));
+
+  start_offset = gtk_text_iter_get_offset(&view->iter);
+  bbs_thread_view_append_text(view, text, len);
+  gtk_text_buffer_get_iter_at_offset(view->text_buffer, &start, start_offset);
+  gtk_text_buffer_apply_tag(view->text_buffer, get_alt_sage_tag(view),
+			    &start, &view->iter);
+  g_hash_table_insert(view->link_table,
+		      (gpointer)start_offset, G_STRDUP(link));
+}
+
+
 void
 bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget)
 {
@@ -1176,9 +1249,22 @@ bbs_thread_view_find_forward_first_match(BBSThreadView *view,
   if (!view->use_regexp && !view->match_case)
     {
       gchar *tmp_text = g_utf8_casefold(text, -1);
-      G_FREE(text);
+      g_free(text);
+#if TRACE_MEMORY_USAGE
+      text = G_STRDUP(tmp_text);
+      g_free(tmp_text);
+#else
       text = tmp_text;
+#endif
     }
+#if TRACE_MEMORY_USAGE
+  else
+    {
+      gchar *tmp_text = text;
+      text = G_STRDUP(text);
+      g_free(tmp_text);
+    }
+#endif
 
   if (view->use_regexp)
     {
