@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.14 2003/06/07 14:35:30 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.17 2003/06/20 18:14:40 fuyu Exp $
  */
 
 #include "config.h"
@@ -63,6 +63,17 @@ static void category_expanded_cb(BoardlistView *view,
 static void category_collapsed_cb(BoardlistView *view,
 				  OchushaBoardCategory *category,
 				  OchushaApplication *application);
+static void toggle_hide_category_cb(BoardlistView *view,
+				    OchushaBoardCategory *category,
+				    OchushaApplication *application);
+static void toggle_hide_board_cb(BoardlistView *view,
+				 OchushaBulletinBoard *board,
+				 OchushaApplication *application);
+static void kill_category_cb(BoardlistView *view,
+			     OchushaBoardCategory *category,
+			     OchushaApplication *application);
+static void kill_board_cb(BoardlistView *view, OchushaBulletinBoard *board,
+			  OchushaApplication *application);
 
 static void boardlist_read_category_element_cb(OchushaBBSTable *table,
 					       OchushaBoardCategory *category,
@@ -91,7 +102,7 @@ static void setup_boardlist(OchushaApplication *application);
 static void filter_toggled_cb(GtkToggleButton *toggle_button,
 			      OchushaApplication *application);
 static void item_view_required_cb(PanedNotebook *paned_notebook,
-				  OchushaBulletinBoard *board, GtkWidget **item_view,
+				  gpointer item, GtkWidget **item_view,
 				  const gchar **title, GtkWidget **tab_label,
 				  OchushaApplication *application);
 static void item_view_being_closed_cb(PanedNotebook *paned_notebook,
@@ -179,6 +190,16 @@ initialize_boardlist(OchushaApplication *application)
 		   G_CALLBACK(category_expanded_cb), application);
   g_signal_connect(G_OBJECT(application->boardlist_view), "category_collapsed",
 		   G_CALLBACK(category_collapsed_cb), application);
+  g_signal_connect(G_OBJECT(application->boardlist_view),
+		   "toggle_hide_category",
+		   G_CALLBACK(toggle_hide_category_cb), application);
+  g_signal_connect(G_OBJECT(application->boardlist_view),
+		   "toggle_hide_board",
+		   G_CALLBACK(toggle_hide_board_cb), application);
+  g_signal_connect(G_OBJECT(application->boardlist_view), "kill_category",
+		   G_CALLBACK(kill_category_cb), application);
+  g_signal_connect(G_OBJECT(application->boardlist_view), "kill_board",
+		   G_CALLBACK(kill_board_cb), application);
 #if TRACE_MEMORY_USAGE
   g_signal_connect(G_OBJECT(application->boardlist_view), "destroy",
 		   G_CALLBACK(gtk_widget_destroyed),
@@ -550,6 +571,13 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
     G_FREE(search_query_data.key);
 
   normalized_key = g_utf8_normalize(key, -1, G_NORMALIZE_ALL);
+#if TRACE_MEMORY_USAGE
+  {
+    gchar *tmp_key = normalized_key;
+    normalized_key = G_STRDUP(tmp_key);
+    g_free(tmp_key);
+  }
+#endif
   if (!match_case)
     {
       gchar *case_normalized_key = g_utf8_casefold(normalized_key, -1);
@@ -728,7 +756,7 @@ fix_filter_button_state(OchushaApplication *application)
     return;
 
   gtk_toggle_button_set_active(application->filter_button,
-			ensure_bulletin_board_info(board)->enable_filter);
+		ensure_bulletin_board_info(board, application)->enable_filter);
 }
 
 
@@ -776,7 +804,7 @@ filter_toggled_cb(GtkToggleButton *toggle_button,
   if (board == NULL)
     return;
 
-  info = ensure_bulletin_board_info(board);
+  info = ensure_bulletin_board_info(board, application);
   if (info->enable_filter == gtk_toggle_button_get_active(toggle_button))
     return;
 
@@ -801,18 +829,23 @@ select_category_cb(BoardlistView *view, OchushaBoardCategory *category,
 
 
 static void
-item_view_required_cb(PanedNotebook *paned_notebook, OchushaBulletinBoard *board,
+item_view_required_cb(PanedNotebook *paned_notebook, gpointer item,
 		      GtkWidget **item_view, const gchar **title,
 		      GtkWidget **tab_label,
 		      OchushaApplication *application)
 {
-  OchushaBulletinBoard *board2;
+  OchushaBulletinBoard *board;
+  if (!OCHUSHA_IS_BULLETIN_BOARD(item))
+    {
+      *tab_label = NULL;
+      *item_view = NULL;
+      return;
+    }
+
+  board = OCHUSHA_BULLETIN_BOARD(item);
   *tab_label = get_tab_label(board->name);
   *item_view = open_bulletin_board(application, board, ICON_LABEL(*tab_label));
 
-  board2 = ochusha_bbs_table_lookup_board_by_url(application->table,
-						 board->base_url);
-
   if (*item_view == NULL)
     {
       gtk_object_sink(GTK_OBJECT(*tab_label));
@@ -837,7 +870,8 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook, OchushaBulletinBoard *b
 			  GtkWidget *item_view,
 			  OchushaApplication *application)
 {
-  OchushaAsyncBuffer *buffer = snatch_subject_txt_buffer_for_board(board);
+  OchushaAsyncBuffer *buffer = snatch_threadlist_source_buffer_for_board(
+							board, application);
 
 #ifndef SUSPEND_ALL_FOR_DESTRUCTION	/* ¸ */
   /*
@@ -952,7 +986,7 @@ page_switched_cb(PanedNotebook *paned_notebook,
       BulletinBoardGUIInfo *info;
 
       g_return_if_fail(board != NULL);
-      info = ensure_bulletin_board_info(board);
+      info = ensure_bulletin_board_info(board, application);
       gtk_paned_set_position(GTK_PANED(new_page),
 			     application->threadlist_height);
       gtk_toggle_button_set_active(application->filter_button,
@@ -980,7 +1014,7 @@ boardlist_read_board_element_cb(OchushaBBSTable *table,
 				GHashTable *board_attributes,
 				OchushaApplication *application)
 {
-  BulletinBoardGUIInfo *info = ensure_bulletin_board_info(board);
+  BulletinBoardGUIInfo *info = ensure_bulletin_board_info(board, application);
   info->enable_filter = ochusha_utils_get_attribute_boolean(board_attributes,
 							    "enable_filter");
   info->filter.rule = ochusha_utils_get_attribute_string(board_attributes,
@@ -1038,7 +1072,7 @@ boardlist_write_board_element_cb(OchushaBBSTable *table,
 				 FILE *boardlist_xml,
 				 OchushaApplication *application)
 {
-  BulletinBoardGUIInfo *info = ensure_bulletin_board_info(board);
+  BulletinBoardGUIInfo *info = ensure_bulletin_board_info(board, application);
   OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, info, enable_filter);
 
   if (info->filter.rule != NULL)
@@ -1081,6 +1115,38 @@ category_collapsed_cb(BoardlistView *view, OchushaBoardCategory *category,
 }
 
 
+static void
+toggle_hide_category_cb(BoardlistView *view, OchushaBoardCategory *category,
+			OchushaApplication *application)
+{
+  category->hidden = !(category->hidden);
+}
+
+
+static void
+toggle_hide_board_cb(BoardlistView *view, OchushaBulletinBoard *board,
+		     OchushaApplication *application)
+{
+  board->hidden = !(board->hidden);
+}
+
+
+static void
+kill_category_cb(BoardlistView *view, OchushaBoardCategory *category,
+		 OchushaApplication *application)
+{
+  category->killed = TRUE;
+}
+
+
+static void
+kill_board_cb(BoardlistView *view, OchushaBulletinBoard *board,
+	      OchushaApplication *application)
+{
+  board->killed = TRUE;
+}
+
+
 static gboolean
 prepare_category(OchushaBoardCategory *category, gpointer user_data)
 {
@@ -1092,11 +1158,55 @@ prepare_category(OchushaBoardCategory *category, gpointer user_data)
 static gboolean
 prepare_board(OchushaBulletinBoard *board, gpointer user_data)
 {
-  ensure_bulletin_board_info(board);
+  ensure_bulletin_board_info(board, (OchushaApplication *)user_data);
   return TRUE;
 }
 
 
+static OchushaBulletinBoard *
+process_board_move(OchushaBulletinBoard *old_board,
+		   OchushaBulletinBoard *new_board,
+		   gpointer user_data)
+{
+#if 0
+  OchushaApplication *application = (OchushaApplication *)user_data;
+#endif  
+  /*
+   * TODO: DATեʤɥå夷ƤǡΰžԤ٤
+   *       İžɤߤGUIɲäɬפ⡣
+   */
+#if DEBUG_GUI
+  fprintf(stderr, "process_board_move: old_board=%p new_board=%p\n",
+	  old_board, new_board);
+#endif
+  return new_board;	/* ǤϿΤͥ */
+}
+
+
+void
+redraw_boardlist(OchushaApplication *application)
+{
+  int status;
+
+  if ((status = pthread_mutex_trylock(&board_list_lock)) != 0)
+    {
+      if (status == EBUSY)
+	return;		/* İι1åɤ */
+
+      fprintf(stderr, "Internal error: invalid mutex.\n");
+      abort();
+    }
+
+  setup_boardlist(application);
+
+  if (pthread_mutex_unlock(&board_list_lock) != 0)
+    {
+      fprintf(stderr, "Couldn't unlock a mutex.\n");
+      abort();
+    }
+}
+
+
 static void
 build_boardlist(WorkerThread *employee, gpointer args)
 {
@@ -1128,7 +1238,7 @@ build_boardlist(WorkerThread *employee, gpointer args)
   if (ochusha_utils_2ch_analyze_bbsmenu(table, buffer,
 					prepare_category,
 					prepare_board,
-					NULL,	/* TODO: İžб */
+					process_board_move,
 					application))
     {
       gdk_threads_enter();
@@ -1163,7 +1273,8 @@ static void
 setup_boardlist(OchushaApplication *application)
 {
   boardlist_view_open(BOARDLIST_VIEW(application->boardlist_view),
-		      application->table->category_list);
+		      application->table->category_list,
+		      application->hide_hidden_boardlist_items);
   g_slist_foreach(application->table->category_list,
 		  (GFunc)restore_expanded_state, application->boardlist_view);
 
