@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: main.c,v 1.4 2003/06/07 14:35:30 fuyu Exp $
+ * $Id: main.c,v 1.5 2003/06/21 16:37:42 fuyu Exp $
  */
 
 #include "config.h"
@@ -101,6 +101,8 @@ main(int argc, char *argv[])
   g_object_unref(G_OBJECT(application->broker));
   application->broker = NULL;
 
+  G_FREE(application->threadlist_view_contents);
+  application->threadlist_view_contents = NULL;
   G_FREE(application->user_default_filter.rule);
   application->user_default_filter.rule = NULL;
   G_FREE(application->web_browser_template);
