@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.12 2003/06/06 19:37:23 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.15 2003/06/21 16:23:53 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -96,10 +96,18 @@
 #define OCHUSHA_DEFAULT_THREAD_TAB_ENABLE_TOOLTIPS			TRUE
 #define OCHUSHA_DEFAULT_SHOW_THREADLIST_ENTRY_WHEN_THREAD_SELECTED	FALSE
 
+#define OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS		"RMTNnUD"
+
+#define OCHUSHA_DEFAULT_ENABLE_POPUP_TITLE				FALSE
+#define OCHUSHA_DEFAULT_ENABLE_POPUP_RESPONSE				TRUE
+
 #define OCHUSHA_DEFAULT_POPUP_DELAY					500
 #define OCHUSHA_DEFAULT_POPUP_CLOSE_DELAY				100
 #define OCHUSHA_DEFAULT_MAXIMUM_NUMBER_OF_POPUP_RESPONSES		5
 
+#define OCHUSHA_DEFAULT_HIDE_HIDDEN_BOARDLIST_ITEMS			FALSE
+#define OCHUSHA_DEFAULT_HIDE_HIDDEN_THREADS				FALSE
+
 
 
 #define OCHUSHA_GTKRC				"ochusha-gtkrc"
@@ -185,12 +193,14 @@ struct _OchushaApplication
   gboolean board_tab_shrinkable;
   guint board_tab_minimum_size;
   gboolean board_tab_enable_tooltips;
+  gboolean hide_hidden_boardlist_items;
 
   gint threadlist_pane_style;
   gboolean thread_tab_shrinkable;
   guint thread_tab_minimum_size;
   gboolean thread_tab_enable_tooltips;
   gboolean show_threadlist_entry_when_thread_selected;
+  char *threadlist_view_contents;
 
 
   /* 쥿Υݥåץå״Ϣ */
@@ -212,6 +222,7 @@ struct _OchushaApplication
 
   /* Υ桼ǥեȥե륿롼 */
   ThreadlistFilter user_default_filter;
+  gboolean hide_hidden_threads;
 
   OchushaNetworkBroker *broker;
 
@@ -224,10 +235,12 @@ typedef enum
   MAIN_MENU_QUIT = 1,
   MAIN_MENU_OPEN_URL,
   MAIN_MENU_REFRESH_BOARDLIST,
+  MAIN_MENU_HIDE_HIDDEN_BOARDLIST_ITEMS,
   MAIN_MENU_REFRESH_THREAD,
   MAIN_MENU_REFRESH_THREAD_ALL,
   MAIN_MENU_REFRESH_THREADLIST,
   MAIN_MENU_REFRESH_THREADLIST_ALL,
+  MAIN_MENU_HIDE_HIDDEN_THREADS,
   MAIN_MENU_ABOUT,
 } OchushaMainMenuAction;
 
