@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.c,v 1.7 2003/06/12 04:13:38 fuyu Exp $
+ * $Id: ochusha_bbs_thread.c,v 1.8 2003/06/22 10:11:10 fuyu Exp $
  */
 
 #include "config.h"
@@ -397,6 +397,7 @@ ochusha_bbs_thread_parse_responses(OchushaBBSThread *thread,
 				   int start, int number,
 				   StartThreadCallback *start_thread_cb,
 				   EachResponseCallback *each_response_cb,
+				   BrokenResponseCallback *broken_response_cb,
 				   EndThreadCallback *end_thread_cb,
 				   gpointer callback_data)
 {
@@ -409,7 +410,8 @@ ochusha_bbs_thread_parse_responses(OchushaBBSThread *thread,
 
   return (*klass->parse_responses)(thread, buffer, start, number,
 				   start_thread_cb, each_response_cb,
-				   end_thread_cb, callback_data);
+				   broken_response_cb, end_thread_cb,
+				   callback_data);
 }
 
 
