@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.5 2003/06/12 04:13:38 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.6 2003/06/22 10:11:10 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -55,6 +55,8 @@ typedef gboolean StartThreadCallback(OchushaBBSThread *thread,
 typedef gboolean EachResponseCallback(OchushaBBSThread *thread, int number,
 				      const OchushaBBSResponse *response,
 				      gpointer callback_data);
+typedef gboolean BrokenResponseCallback(OchushaBBSThread *thread, int number,
+					gpointer callback_data);
 typedef gboolean EndThreadCallback(OchushaBBSThread *thread, gboolean finished,
 				   gpointer callback_data);
 
@@ -105,6 +107,7 @@ struct _OchushaBBSThreadClass
 			      int start, int number,
 			      StartThreadCallback *start_thread_callback,
 			      EachResponseCallback *each_response_callback,
+			      BrokenResponseCallback *broken_response_callback,
 			      EndThreadCallback *end_thread_callback,
 			      gpointer callback_data);
   const char *(*get_url)(OchushaBBSThread *thread);
@@ -180,6 +183,7 @@ gboolean ochusha_bbs_thread_parse_responses(OchushaBBSThread *thread,
 					    int start, int number,
 					    StartThreadCallback *start_cb,
 					    EachResponseCallback *response_cb,
+					    BrokenResponseCallback *broken_cb,
 					    EndThreadCallback *end_cb,
 					    gpointer callback_data);
 void ochusha_bbs_thread_remove_cache(OchushaBBSThread *thread,
