@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.4 2003/06/07 14:35:32 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.5 2003/06/21 19:19:22 fuyu Exp $
  */
 
 #include "config.h"
@@ -185,7 +185,8 @@ extract_boards(OchushaBBSTable *table, OchushaBoardCategory *category,
 	      g_object_unref(G_OBJECT(board));
 	    }
 	}
-      
+
+      board->killed = FALSE;
       ochusha_board_category_add_board(category, board);
 
     search_next:
@@ -319,6 +320,7 @@ ochusha_utils_2ch_analyze_bbsmenu(OchushaBBSTable *table,
 	      g_object_unref(G_OBJECT(category));
 	    else
 	      {
+		category->killed = FALSE;
 		ochusha_bbs_table_add_category(table, category);
 		if (category_callback != NULL
 		    && !(*category_callback)(category, callback_data))
